# from folder.folder.file import class

from ggwp.EzDataModel.DataModel import *
from ggwp.EzDataModel.RFMT import *
from ggwp.EzDataModel.Cohort import *
from ggwp.EzDataModel.CustomerMovement import *
from ggwp.EzDataModel.BasketEvolving import *


import configparser

config_path  = './config.cfg'
parser = configparser.ConfigParser()
parser.read(config_path)
version = parser['default']['version']

print(version)

# print('test')

import os

print(os.getcwd())